@@ -1,7 +1,6 @@
 use crate::node::{Node, NodeContainer};
 use std::borrow::BorrowMut;
-use crate::DefaultModifiers;
-use crate::renderer::{Renderable};
+use crate::{DefaultModifiers, Renderable};
 use html_escape::encode_text;
 
 /// Used to set the typographic style of a Text view.
